@@ -11,115 +11,62 @@ contain a list of valid parameter values. These values are defined by a
 printable 'name' and an associated 'value'.
 """
 
-from flowserv.model.parameter.base import ParameterBase
+from __future__ import annotations
+from typing import Any, Dict, List, Optional, Union
+
+from flowserv.model.parameter.base import Parameter, PARA_SELECT
 
 import flowserv.error as err
 import flowserv.model.parameter.base as pd
 import flowserv.util as util
 
 
-"""Unique parameter type identifier."""
-PARA_ENUM = 'enum'
-
-
-class EnumParameter(ParameterBase):
-    """Enumeration parameter type. Extends the base parameter with a list of
-    possible argument values.
+class Select(Parameter):
+    """Enumeration parameter type for select boxes. Extends the base parameter
+    with a list of possible argument values.
     """
     def __init__(
-        self, para_id, name, index, values, description=None,
-        default_value=None, is_required=False, module_id=None
+        self, name: str, values: List[Dict], index: Optional[int] = 0,
+        label: Optional[str] = None, help: Optional[str] = None,
+        default: Optional[bool] = None, required: Optional[bool] = False,
+        group: Optional[str] = None
     ):
-        """Initialize the base properties a enumeration parameter declaration.
+        """Initialize the base properties for a select parameter declaration.
 
         Parameters
         ----------
-        para_id: string
-            Unique parameter identifier
         name: string
-            Human-readable parameter name.
-        index: int
+            Unique parameter identifier
+        index: int, default=0
             Index position of the parameter (for display purposes).
         values: list
             List of dictionary serializations containing enumeration of valid
             parameter values.
-        description: string, default=None
+        label: string, default=None
+            Human-readable parameter name.
+        help: string, default=None
             Descriptive text for the parameter.
-        default_value: any, default=None
+        default: bool, default=None
             Optional default value.
-        is_required: bool, default=False
+        required: bool, default=False
             Is required flag.
-        module_id: string, default=None
+        group: string, default=None
             Optional identifier for parameter group that this parameter
             belongs to.
         """
-        super(EnumParameter, self).__init__(
-            para_id=para_id,
-            type_id=PARA_ENUM,
+        super(Select, self).__init__(
+            dtype=PARA_SELECT,
             name=name,
             index=index,
-            description=description,
-            default_value=default_value,
-            is_required=is_required,
-            module_id=module_id
+            label=label,
+            help=help,
+            default=default,
+            required=required,
+            group=group
         )
         self.values = values
 
-    @classmethod
-    def from_dict(cls, doc, validate=True):
-        """Get enumeration parameter instance from dictionary serialization.
-
-        Parameters
-        ----------
-        doc: dict
-            Dictionary serialization for enumeration parameter.
-        validate: bool, default=True
-            Validate the serialized object if True.
-
-        Returns
-        -------
-        flowserv.model.parameter.enum.EnumParameter
-
-        Raises
-        ------
-        flowserv.error.InvalidParameterError
-        """
-        if validate:
-            try:
-                util.validate_doc(
-                    doc,
-                    mandatory=[
-                        pd.ID,
-                        pd.TYPE,
-                        pd.NAME,
-                        pd.INDEX,
-                        pd.REQUIRED,
-                        'values'
-                    ],
-                    optional=[pd.DESC, pd.DEFAULT, pd.MODULE]
-                )
-                for val in doc['values']:
-                    util.validate_doc(
-                        val,
-                        mandatory=['name', 'value'],
-                        optional=['isDefault']
-                    )
-            except ValueError as ex:
-                raise err.InvalidParameterError(str(ex))
-            if doc[pd.TYPE] != PARA_ENUM:
-                raise ValueError("invalid type '{}'".format(doc[pd.TYPE]))
-        return cls(
-            para_id=doc[pd.ID],
-            name=doc[pd.NAME],
-            index=doc[pd.INDEX],
-            description=doc.get(pd.DESC),
-            default_value=doc.get(pd.DEFAULT),
-            is_required=doc[pd.REQUIRED],
-            module_id=doc.get(pd.MODULE),
-            values=doc['values']
-        )
-
-    def to_argument(self, value):
+    def cast(self, value: Any) -> Any:
         """Ensure that the given value is valid. If the value is not contained
         in the enumerated list of values an error is raised.
 
@@ -141,7 +88,53 @@ class EnumParameter(ParameterBase):
                 return value
         raise err.InvalidArgumentError("unknown value '{}'".format(value))
 
-    def to_dict(self):
+    @staticmethod
+    def from_dict(doc: Dict, validate: Optional[bool] = True) -> Select:
+        """Get select parameter instance from a dictionary serialization.
+
+        Parameters
+        ----------
+        doc: dict
+            Dictionary serialization for select parameter declaration.
+        validate: bool, default=True
+            Validate the serialized object if True.
+
+        Returns
+        -------
+        flowserv.model.parameter.enum.Select
+
+        Raises
+        ------
+        flowserv.error.InvalidParameterError
+        """
+        if validate:
+            util.validate_doc(
+                doc,
+                mandatory=pd.MANDATORY + ['values'],
+                optional=pd.OPTIONAL,
+                exception=err.InvalidParameterError
+            )
+            for val in doc['values']:
+                util.validate_doc(
+                    val,
+                    mandatory=['name', 'value'],
+                    optional=['isDefault'],
+                    exception=err.InvalidParameterError
+                )
+            if doc[pd.TYPE] != PARA_SELECT:
+                raise ValueError("invalid type '{}'".format(doc[pd.TYPE]))
+        return Select(
+            name=doc[pd.NAME],
+            index=doc[pd.INDEX],
+            label=doc[pd.LABEL],
+            help=doc.get(pd.HELP),
+            default=doc.get(pd.DEFAULT),
+            required=doc[pd.REQUIRED],
+            group=doc.get(pd.GROUP),
+            values=doc['values']
+        )
+
+    def to_dict(self) -> Dict:
         """Get dictionary serialization for the parameter declaration. Adds
         list of enumerated values to the base serialization.
 
@@ -152,3 +145,26 @@ class EnumParameter(ParameterBase):
         obj = super().to_dict()
         obj['values'] = self.values
         return obj
+
+
+def Option(name: str, value: Union[str, int], default: Optional[bool] = None) -> Dict:
+    """Get a dictionary serialization for an element in the enumeration of valid
+    values for a select parameter.
+
+    Parameters
+    ----------
+    name: string
+        Option display name.
+    value: string or int
+        Returned value if this option is selected.
+    default: bool, default=None
+        Indicate if this is the default option for the selection.
+
+    Returns
+    -------
+    dict
+    """
+    doc = {'name': name, 'value': value}
+    if default is not None:
+        doc['isDefault'] = default
+    return doc
