@@ -10,16 +10,19 @@
 about workflow runs in an underlying database.
 """
 
+import io
 import mimetypes
 import os
 import shutil
+import tarfile
 
-from typing import IO, List, Optional, Tuple, Union
+from typing import IO, List, Optional
 
 from flowserv.model.base import (
     RunFile, RunHandle, RunMessage, WorkflowRankingRun
 )
-
+from flowserv.model.files.base import DatabaseFile
+from flowserv.model.files.fs import walk
 import flowserv.error as err
 import flowserv.model.workflow.state as st
 import flowserv.util as util
@@ -130,7 +133,7 @@ class RunManager(object):
         # changes before deleting the directory.
         self.session.delete(run)
         self.session.commit()
-        self.fs.delete_file(key=rundir)
+        self.fs.delete_folder(key=rundir)
 
     def delete_obsolete_runs(
         self, date: str, state: Optional[str] = None
@@ -207,16 +210,24 @@ class RunManager(object):
         run = self.get_run(run_id)
         if not run.is_success():
             raise err.UnknownRunError(run_id)
-        # Get archive of all run result files from the file store.
+        # Create a memory buffer for the tar file.
+        io_buffer = io.BytesIO()
+        tar_handle = tarfile.open(fileobj=io_buffer, mode='w:gz')
+        # Get file objects for all run result files.
         workflow_id = run.workflow.workflow_id
-        return self.fs.download_archive(
-            src=self.fs.run_basedir(workflow_id=workflow_id, run_id=run_id),
-            files=[f.key for f in run.files]
-        )
+        rundir = self.fs.run_basedir(workflow_id=workflow_id, run_id=run_id)
+        for f in run.files:
+            file = self.fs.load_file(os.path.join(rundir, f.key)).open()
+            info = tarfile.TarInfo(name=f.key)
+            info.size = file.getbuffer().nbytes
+            tar_handle.addfile(tarinfo=info, fileobj=file)
+        tar_handle.close()
+        io_buffer.seek(0)
+        return io_buffer
 
     def get_runfile(
         self, run_id: str, file_id: str = None, key: str = None
-    ) -> Tuple[RunFile, Union[str, IO]]:
+    ) -> DatabaseFile:
         """Get handle and file object for a given run result file. The file is
         either identified by the unique file identifier or the file key.Raises
         an error if the specified file does not exist.
@@ -230,7 +241,7 @@ class RunManager(object):
 
         Returns
         -------
-        (flowserv.model.base.RunFile, string or io.BytesIO)
+        flowserv.model.files.base.DatabaseFile
 
         Raises
         ------
@@ -252,7 +263,11 @@ class RunManager(object):
         # Return file handle for resource file
         workflow_id = run.workflow.workflow_id
         rundir = self.fs.run_basedir(workflow_id=workflow_id, run_id=run_id)
-        return fh, self.fs.load_file(os.path.join(rundir, fh.key))
+        return DatabaseFile(
+            name=fh.name,
+            mime_type=fh.mime_type,
+            fileobj=self.fs.load_file(os.path.join(rundir, fh.key))
+        )
 
     def list_runs(self, group_id, state=None):
         """Get list of run handles for all runs that are associated with a
@@ -403,34 +418,43 @@ class RunManager(object):
                 msg = 'cannot set run in {} state to error state'
                 raise err.ConstraintViolationError(msg.format(current_state))
             assert rundir is not None
-            # Create list of output files depending on whether files are
+            # Create list of output file keyss depending on whether files are
             # specified in the workflow specification or not.
-            runfiles = None
-            if run.outputs() is not None:
+            filekeys = None
+            outputs = run.outputs()
+            if outputs:
                 # List only existing files for output specifications in the
-                # workflow handle.
-                runfiles = [f.source for f in run.outputs()]
+                # workflow handle. Note that (i) the result of run.outputs() is
+                # always a dictionary and (ii) that the keys in the returned
+                # dictionary are not necessary equal to the file sources.
+                filekeys = [f.source for f in run.outputs().values()]
             else:
                 # List all files that were generated by the workflow run as
                 # output.
-                runfiles = state.files
+                filekeys = state.files
             # For each run file ensure that it exist before adding a file
-            # handle to the run.
-            files = list()
-            for filekey in runfiles:
+            # handle to the run. We use the file system store's walk method to
+            # get a list of all files that need to be retained for a run.
+            walklist = list()
+            for filekey in filekeys:
                 filename = os.path.join(rundir, filekey)
                 if not os.path.exists(filename):
                     continue
-                mime_type, _ = mimetypes.guess_type(url=filename)
+                walklist.append((filename, filekey))
+            # Get files that will be copied to the file store.
+            runfiles = list()
+            storefiles = walk(files=walklist)
+            for file, filekey in storefiles:
+                mime_type, _ = mimetypes.guess_type(url=file.filename)
                 rf = RunFile(
                     key=filekey,
                     name=filekey,
                     mime_type=mime_type,
-                    size=os.stat(filename).st_size
+                    size=file.size()
                 )
-                files.append(rf)
+                runfiles.append(rf)
             # Set run properties.
-            run.files = files
+            run.files = runfiles
             run.started_at = state.started_at
             run.ended_at = state.finished_at
             # Parse run result if the associated workflow has a result schema.
@@ -455,14 +479,11 @@ class RunManager(object):
                     run.result = values
             # Archive run files (and remove all other files from the run
             # directory).
-            targetdir = self.fs.run_basedir(
+            storedir = self.fs.run_basedir(
                 workflow_id=run.workflow.workflow_id,
                 run_id=run_id
             )
-            self.fs.copy_files(
-                src=rundir,
-                files=[(f.key, os.path.join(targetdir, f.key)) for f in files]
-            )
+            self.fs.store_files(files=storefiles, dst=storedir)
             if os.path.exists(rundir):
                 # The run directory does not have to exist if the workflow does
                 # not access and files or create any files. If the workflow is
